# OLAF BEHEAD PUNY FILES!

```
    ,   |\ ,__
    |\   \/   `.
    \ `-.:.     `\      _____ __    _____ _____
     `-.__ `\=====|    |     |  |  |  _  |   __|
        /=`'/   ^_\    |  |  |  |__|     |   __|
      .'   /\   .=)    |_____|_____|__|__|__|
   .-'  .'|  '-(/_|
 .'  __(  \  .'`             THE BEHEADER
/_.'`  `.  |`
         \ |
          |/

usage: olaf-the-beheader [-h] [-n LINE_COUNT] [PATTERN [PATTERN ...]]

OLAF BEHEAD PUNY FILES!

positional arguments:
  PATTERN        a pattern of puny files to behead, defaults to all files in
                 the current directory

optional arguments:
  -h, --help     show this help message and exit
  -n LINE_COUNT  number of lines to behead from puny files, defaults to 10
```
